@@ -31,12 +31,8 @@
 
 #include <QDBusObjectPath>
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
 // logging category for this framework, default: log stuff >= warning
 Q_LOGGING_CATEGORY(NMQT, "networkmanager-qt", QtWarningMsg)
-#else
-Q_LOGGING_CATEGORY(NMQT, "networkmanager-qt")
-#endif
 
 namespace NetworkManager
 {
@@ -99,8 +95,8 @@ NetworkManager::DevicePrivate::DevicePrivate(const QString &path, NetworkManager
 #endif
     , uni(path)
     , designSpeed(0)
-    , dhcp4Config(0)
-    , dhcp6Config(0)
+    , dhcp4Config(nullptr)
+    , dhcp6Config(nullptr)
     , mtu(0)
     , q_ptr(q)
 {
@@ -123,7 +119,9 @@ void NetworkManager::DevicePrivate::init()
 
     // This needs to be initialized as soon as possible, because based on this property
     // we initialize the device type
-    deviceType = static_cast<Device::Type>(deviceIface.deviceType());
+    deviceType = convertType(deviceIface.deviceType());
+
+    deviceStatistics = DeviceStatistics::Ptr(new NetworkManager::DeviceStatistics(uni), &QObject::deleteLater);
 
     // Get all Device's properties at once
     QVariantMap initialProperties = NetworkManagerPrivate::retrieveInitialProperties(deviceIface.staticInterfaceName(), uni);
@@ -159,6 +157,40 @@ NetworkManager::Device::StateChangeReason NetworkManager::DevicePrivate::convert
     return ourReason;
 }
 
+NetworkManager::Device::Type NetworkManager::DevicePrivate::convertType(uint type)
+{
+    // These are identical to NM enums
+    if (type <= NM_DEVICE_TYPE_TEAM) {
+        return (NetworkManager::Device::Type)type;
+    }
+
+    switch (type) {
+    case 16:
+        // NM_DEVICE_TYPE_TUN
+        return NetworkManager::Device::Tun;
+    case 17:
+        // NM_DEVICE_TYPE_IP_TUNNEL
+        return NetworkManager::Device::IpTunnel;
+    case 18:
+        // NM_DEVICE_TYPE_MACVLAN
+        return NetworkManager::Device::MacVlan;
+    case 19:
+        // NM_DEVICE_TYPE_VXLAN
+        return NetworkManager::Device::VxLan;
+    case 20:
+        // NM_DEVICE_TYPE_VETH
+        return NetworkManager::Device::Veth;
+    case 21:
+        // NM_DEVICE_TYPE_MACSEC
+        return NetworkManager::Device::MacSec;
+    case 22:
+        // NM_DEVICE_TYPE_DUMMY
+        return NetworkManager::Device::Dummy;
+    }
+
+    return NetworkManager::Device::UnknownType;
+}
+
 NetworkManager::Device::Device(const QString &path, QObject *parent)
     : QObject(parent)
     , d_ptr(new DevicePrivate(path, this))
@@ -528,6 +560,12 @@ QVariant NetworkManager::Device::capabilitiesV() const
     return QVariant(d->capabilities);
 }
 
+NetworkManager::DeviceStatistics::Ptr NetworkManager::Device::deviceStatistics() const
+{
+    Q_D(const Device);
+    return d->deviceStatistics;
+}
+
 void NetworkManager::DevicePrivate::deviceStateChanged(uint newState, uint oldState, uint reason)
 {
     Q_Q(Device);
@@ -540,7 +578,7 @@ void NetworkManager::DevicePrivate::deviceStateChanged(uint newState, uint oldSt
 void NetworkManager::DevicePrivate::dbusPropertiesChanged(const QString &interfaceName, const QVariantMap &properties, const QStringList &invalidatedProperties)
 {
     Q_UNUSED(invalidatedProperties);
-    if (interfaceName.contains(QLatin1String("org.freedesktop.NetworkManager.Device"))) {
+    if (interfaceName.contains(QLatin1String("org.freedesktop.NetworkManager.Device")) && interfaceName != QLatin1String("org.freedesktop.NetworkManager.Device.Statistics")) {
         propertiesChanged(properties);
     }
 }
