@@ -28,7 +28,6 @@
 #include <QtCore/QStringList>
 #include <QtNetwork/QHostAddress>
 
-#if NM_CHECK_VERSION(1, 0, 0)
 #define NMQT_SETTING_IP4_CONFIG_SETTING_NAME       NM_SETTING_IP4_CONFIG_SETTING_NAME
 #define NMQT_SETTING_IP4_CONFIG_METHOD             NM_SETTING_IP_CONFIG_METHOD
 #define NMQT_SETTING_IP4_CONFIG_DNS                NM_SETTING_IP_CONFIG_DNS
@@ -49,28 +48,7 @@
 #define NMQT_SETTING_IP4_CONFIG_METHOD_MANUAL      NM_SETTING_IP4_CONFIG_METHOD_MANUAL
 #define NMQT_SETTING_IP4_CONFIG_METHOD_SHARED      NM_SETTING_IP4_CONFIG_METHOD_SHARED
 #define NMQT_SETTING_IP4_CONFIG_METHOD_DISABLED    NM_SETTING_IP4_CONFIG_METHOD_DISABLED
-#else
-#define NMQT_SETTING_IP4_CONFIG_SETTING_NAME       NM_SETTING_IP4_CONFIG_SETTING_NAME
-#define NMQT_SETTING_IP4_CONFIG_METHOD             NM_SETTING_IP4_CONFIG_METHOD
-#define NMQT_SETTING_IP4_CONFIG_DNS                NM_SETTING_IP4_CONFIG_DNS
-#define NMQT_SETTING_IP4_CONFIG_DNS_SEARCH         NM_SETTING_IP4_CONFIG_DNS_SEARCH
-#define NMQT_SETTING_IP4_CONFIG_ADDRESSES          NM_SETTING_IP4_CONFIG_ADDRESSES
-#define NMQT_SETTING_IP4_CONFIG_GATEWAY            NM_SETTING_IP4_CONFIG_GATEWAY
-#define NMQT_SETTING_IP4_CONFIG_ROUTES             NM_SETTING_IP4_CONFIG_ROUTES
-#define NMQT_SETTING_IP4_CONFIG_ROUTE_METRIC       NM_SETTING_IP4_CONFIG_ROUTE_METRIC
-#define NMQT_SETTING_IP4_CONFIG_IGNORE_AUTO_ROUTES NM_SETTING_IP4_CONFIG_IGNORE_AUTO_ROUTES
-#define NMQT_SETTING_IP4_CONFIG_IGNORE_AUTO_DNS    NM_SETTING_IP4_CONFIG_IGNORE_AUTO_DNS
-#define NMQT_SETTING_IP4_CONFIG_DHCP_HOSTNAME      NM_SETTING_IP4_CONFIG_DHCP_HOSTNAME
-#define NMQT_SETTING_IP4_CONFIG_DHCP_SEND_HOSTNAME NM_SETTING_IP4_CONFIG_DHCP_SEND_HOSTNAME
-#define NMQT_SETTING_IP4_CONFIG_NEVER_DEFAULT      NM_SETTING_IP4_CONFIG_NEVER_DEFAULT
-#define NMQT_SETTING_IP4_CONFIG_MAY_FAIL           NM_SETTING_IP4_CONFIG_MAY_FAIL
-#define NMQT_SETTING_IP4_CONFIG_DHCP_CLIENT_ID     NM_SETTING_IP4_CONFIG_DHCP_CLIENT_ID
-#define NMQT_SETTING_IP4_CONFIG_METHOD_AUTO        NM_SETTING_IP4_CONFIG_METHOD_AUTO
-#define NMQT_SETTING_IP4_CONFIG_METHOD_LINK_LOCAL  NM_SETTING_IP4_CONFIG_METHOD_LINK_LOCAL
-#define NMQT_SETTING_IP4_CONFIG_METHOD_MANUAL      NM_SETTING_IP4_CONFIG_METHOD_MANUAL
-#define NMQT_SETTING_IP4_CONFIG_METHOD_SHARED      NM_SETTING_IP4_CONFIG_METHOD_SHARED
-#define NMQT_SETTING_IP4_CONFIG_METHOD_DISABLED    NM_SETTING_IP4_CONFIG_METHOD_DISABLED
-#endif
+
 
 namespace NetworkManager
 {
@@ -108,6 +86,9 @@ public:
     void setRoutes(const QList<NetworkManager::IpRoute> &ipv4routes);
     QList<NetworkManager::IpRoute> routes() const;
 
+    void setRouteMetric(int metric);
+    int routeMetric() const;
+
     void setIgnoreAutoRoutes(bool ignore);
     bool ignoreAutoRoutes() const;
 
